﻿namespace Ecng.Trading.Xaml
{
	using System;
	using System.Collections.Generic;
	using System.Linq;
	using System.Windows.Controls;

	using Ecng.Common;
	using Ecng.Xaml;
	using Ecng.Trading.BusinessEntities;

	/// <summary>
	/// Визуальный контрол-таблица, отображающая заявки (коллекцию объектов класса <see cref="Order"/>).
	/// </summary>
	public partial class OrderGrid
	{
		/// <summary>
		/// Создать объект класса <see cref="OrderGrid"/>.
		/// </summary>
		public OrderGrid()
		{
			this.Orders = new ThreadSafeObservableCollection<Order>();
			InitializeComponent();
		}

		/// <summary>
		/// Коллекция заявок, которые необходимо отобразить.
		/// </summary>
		public IList<Order> Orders { get; private set; }

		/// <summary>
		/// Происходит при новом выделении заявки.
		/// </summary>
		public event EventHandler<EventArgs> OrderSelected;

		/// <summary>
		/// Выбранная заявка.
		/// </summary>
		public Order SelectedOrder
		{
			get
			{
				return this.SelectedOrders.FirstOrDefault();
			}
		}

		/// <summary>
		/// Выбранный заявки.
		/// </summary>
		public IEnumerable<Order> SelectedOrders
		{
			get
			{
				return _orders.SelectedItems.Cast<Order>();
			}
		}

		private void _orders_SelectionChanged(object sender, SelectionChangedEventArgs e)
		{
			this.OrderSelected.SafeInvoke(this);
		}
	}
}