﻿namespace Ecng.Trading.Xaml
{
	using System;
	using System.Collections.ObjectModel;
	using System.Linq;
	using System.Net;
	using System.Windows.Controls;

	using Ecng.Common;
	using Ecng.Trading.Smart;

	/// <summary>
	/// Комбо элемент для выбора адреса сервера SmartCOM.
	/// </summary>
	public class SmartAddressComboBox : ComboBox
	{
		private sealed class ComboItem
		{
			public ComboItem(IPAddress address, string title)
			{
				if (address == null)
					throw new ArgumentNullException("address");

				if (title.IsEmpty())
					throw new ArgumentNullException("title");

				this.Address = address;
				this.Title = title + " ({0})".Put(address);
			}

			public IPAddress Address { get; set; }
			public string Title { get; set; }
		}

		private readonly ObservableCollection<ComboItem> _items = new ObservableCollection<ComboItem>();

		/// <summary>
		/// Создать комбо.
		/// </summary>
		public SmartAddressComboBox()
		{
			base.DisplayMemberPath = "Title";
			base.Width = 170;

			base.ItemsSource = _items;

			_items.Add(new ComboItem(SmartAddresses.Major, "Основной"));
			_items.Add(new ComboItem(SmartAddresses.Demo, "Демо"));
			_items.Add(new ComboItem(SmartAddresses.Minor, "Резервный"));
			_items.Add(new ComboItem(SmartAddresses.Stalker, "Сталкер"));

			base.SelectedIndex = 0;
		}

		/// <summary>
		/// Выбранный адрес сервера SmartCOM.
		/// </summary>
		public IPAddress SelectedAddress
		{
			get { return base.SelectedIndex == -1 ? null : ((ComboItem)base.SelectedItem).Address; }
			set
			{
				if (value == null)
					base.SelectedIndex = -1;
				else
				{
					var item = _items.FirstOrDefault(i => i.Address.Compare(value) == 0);

					if (item == null)
					{
						item = new ComboItem(value, value.ToString());
						_items.Add(item);
					}

					base.SelectedItem = item;
				}
			}
		}
	}
}