﻿namespace Ecng.Trading.Xaml
{
	using System.Collections.Generic;

	using Hardcodet.Wpf.GenericTreeView;

	class StrategyNodeTree : TreeViewBase<StrategyNode>
	{
		public StrategyNodeTree()
		{
			base.ObserveChildItems = true;
		}

		/// <summary>
		/// Generates a unique identifier for a given item that is represented as a node of the tree.
		/// </summary>
		/// <param name="item">An item which is represented by a tree node.</param>
		/// <returns>A unique key that represents the item.</returns>
		public override string GetItemKey(StrategyNode item)
		{
			return item.Strategy.Id.ToString();
		}

		/// <summary>
		/// Gets all child items of a given parent item. The tree needs this method to properly traverse the
		/// logic tree of a given item.<br/>
		/// Important: If you plan to have the tree automatically update itself if nested content is being changed, you
		/// the <see cref="P:Hardcodet.Wpf.GenericTreeView.TreeViewBase`1.ObserveChildItems"/> property must be
		/// true, and the collection that is being returned needs to implement the <see cref="T:System.Collections.Specialized.INotifyCollectionChanged"/>
		/// interface (e.g. by returning an collection of type <see cref="T:System.Collections.ObjectModel.ObservableCollection`1"/>.
		/// </summary>
		/// <param name="parent">A currently processed item that is being represented as a node of the tree.</param>
		/// <returns>
		/// All child items to be represented by the tree. The returned collection needs to implement
		/// <see cref="T:System.Collections.Specialized.INotifyCollectionChanged"/> if the
		/// <see cref="P:Hardcodet.Wpf.GenericTreeView.TreeViewBase`1.ObserveChildItems"/> feature is supposed to work.
		/// </returns>
		/// <remarks>
		/// If this is an expensive operation, you should override <see cref="M:Hardcodet.Wpf.GenericTreeView.TreeViewBase`1.HasChildItems(`0)"/>
		/// which invokes this method by default.
		/// </remarks>
		public override ICollection<StrategyNode> GetChildItems(StrategyNode parent)
		{
			return parent.ChildNodes;
		}

		/// <summary>
		/// Gets the parent of a given item, if available. If the item is a top-level element, this method is supposed to return a null reference.
		/// </summary>
		/// <param name="item">The currently processed item.</param>
		/// <returns>The parent of the item, if available.</returns>
		public override StrategyNode GetParentItem(StrategyNode item)
		{
			return item.ParentNode;
		}
	}
}